Skip to content

Commit

Permalink
MCOld
Browse files Browse the repository at this point in the history
  • Loading branch information
Lumine1909 committed Jun 26, 2024
1 parent c417254 commit e542d14
Show file tree
Hide file tree
Showing 2 changed files with 73 additions and 0 deletions.
42 changes: 42 additions & 0 deletions patches/server/0126-MCOld-allow-grindstone-overstacking.patch
Original file line number Diff line number Diff line change
@@ -0,0 +1,42 @@
From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001
From: Lumine1909 <133463833+Lumine1909@users.noreply.github.com>
Date: Wed, 26 Jun 2024 17:59:56 +0800
Subject: [PATCH] MCOld-allow-grindstone-overstacking


diff --git a/src/main/java/net/minecraft/world/inventory/GrindstoneMenu.java b/src/main/java/net/minecraft/world/inventory/GrindstoneMenu.java
index 1678f6c8b2c7db761783e53043169bf12bc2cb29..4bfea8b5139a10a3dd76d56159a1914a5ddc7c8f 100644
--- a/src/main/java/net/minecraft/world/inventory/GrindstoneMenu.java
+++ b/src/main/java/net/minecraft/world/inventory/GrindstoneMenu.java
@@ -202,7 +202,7 @@ public class GrindstoneMenu extends AbstractContainerMenu {
byte b0 = 1;

if (!firstInput.isDamageableItem()) {
- if (firstInput.getMaxStackSize() < 2 || !ItemStack.matches(firstInput, secondInput)) {
+ if (!org.leavesmc.leaves.LeavesConfig.allowGrindstoneOverstacking && firstInput.getMaxStackSize() < 2 || !ItemStack.matches(firstInput, secondInput)) { // Leaves - allowGrindstoneOverstaking
return ItemStack.EMPTY;
}

@@ -286,7 +286,7 @@ public class GrindstoneMenu extends AbstractContainerMenu {
ItemStack itemstack3 = this.repairSlots.getItem(1);

if (slot == 2) {
- if (!this.moveItemStackTo(itemstack1, 3, 39, true)) {
+ if (!this.moveItemStackTo(itemstack1, 3, 39, true, true)) { // Leaves - allowGrindstoneOverstacking: Disable stack check
return ItemStack.EMPTY;
}

From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001
From: Lumine1909 <133463833+Lumine1909@users.noreply.github.com>
Date: Wed, 26 Jun 2024 18:15:57 +0800
Subject: [PATCH] MCOld-MC-67


diff --git a/src/main/java/net/minecraft/world/entity/Entity.java b/src/main/java/net/minecraft/world/entity/Entity.java
index b450c19fbb6cc7266db4ddc4bc86546ca2054d5a..69d2ee3bd4e89968da219f27231af241c88b3600 100644
--- a/src/main/java/net/minecraft/world/entity/Entity.java
+++ b/src/main/java/net/minecraft/world/entity/Entity.java
@@ -3753,7 +3753,7 @@ public abstract class Entity implements SyncedDataHolder, Nameable, EntityAccess
}

public boolean canChangeDimensions(Level from, Level to) {
- return this.isAlive() && this.valid; // Paper - Fix item duplication and teleport issues
+ return !(this.isPassenger() || this.isVehicle() && !org.leavesmc.leaves.LeavesConfig.allowEntityPortalWithPassenger) && this.isAlive() && this.valid; // Paper - Fix item duplication and teleport issues // Leaves - allowEntityPortalWithPassenger
}

public float getBlockExplosionResistance(Explosion explosion, BlockGetter world, BlockPos pos, BlockState blockState, FluidState fluidState, float max) {
diff --git a/src/main/java/org/leavesmc/leaves/LeavesConfig.java b/src/main/java/org/leavesmc/leaves/LeavesConfig.java
index 6ad969d47898199bfa2d73ecda3d26d3c4719520..799fa0e780431cd690b86f3340850dd85a2e4884 100644
--- a/src/main/java/org/leavesmc/leaves/LeavesConfig.java
+++ b/src/main/java/org/leavesmc/leaves/LeavesConfig.java
@@ -921,5 +921,7 @@ public final class LeavesConfig {
@GlobalConfig(name = "allow-grindstone-overstacking", category = "fix")
public static boolean allowGrindstoneOverstacking = false;

+ @GlobalConfig(name = "allow-entity-portal-with-passenger", category = "fix")
+ public static boolean allowEntityPortalWithPassenger = true;
// Leaves end - fix
}

0 comments on commit e542d14

Please sign in to comment.
diff --git a/src/main/java/org/leavesmc/leaves/LeavesConfig.java b/src/main/java/org/leavesmc/leaves/LeavesConfig.java
index 2a7f9d9fdb72786b08b3cb216f5aa5e5eac3c967..6ad969d47898199bfa2d73ecda3d26d3c4719520 100644
--- a/src/main/java/org/leavesmc/leaves/LeavesConfig.java
+++ b/src/main/java/org/leavesmc/leaves/LeavesConfig.java
@@ -918,5 +918,8 @@ public final class LeavesConfig {
@GlobalConfig(name = "vanilla-hopper", category = "fix")
public static boolean vanillaHopper = false;

- // Leaves end - region
+ @GlobalConfig(name = "allow-grindstone-overstacking", category = "fix")
+ public static boolean allowGrindstoneOverstacking = false;
+
+ // Leaves end - fix
}
31 changes: 31 additions & 0 deletions patches/server/0127-MCOld-MC-67.patch
Original file line number Diff line number Diff line change
@@ -0,0 +1,31 @@